@@ -45,7 +45,7 @@ class Board(Copyable):
             testline = self.walls[-1]
         self.holes = testline.find('  ') >= 0
         self.playingboard = 0
-        self.bonuslevel = not self.monsters
+        self.bonuslevel = not self.monsters or (gamesrv.game.finalboard is not None and self.num >= gamesrv.game.finalboard)
         self.cleaning_gen_state = 0
 
     def set_musics(self, prefix=[]):
@@ -208,20 +208,21 @@ class Board(Copyable):
                 else:
                     s.kill()
         # add monsters
-        import monsters
-        f_monsters = gamesrv.game.f_monsters
-        if f_monsters < 0.1:
-            f_monsters = max(1.0, min(2.0, (len(playing)-2)/2.2+1.0))
-        for mdef in self.monsters:
-            if not fastreenter:
-                yield 2
-            cls = getattr(monsters, mdef.__class__.__name__)
-            dir = mdef.dir
-            i = random.random()
-            while i < f_monsters:
-                cls(mdef, dir=dir)
-                dir = -dir
-                i += 1.0
+        if not self.bonuslevel:
+            import monsters
+            f_monsters = gamesrv.game.f_monsters
+            if f_monsters < 0.1:
+                f_monsters = max(1.0, min(2.0, (len(playing)-2)/2.2+1.0))
+            for mdef in self.monsters:
+                if not fastreenter:
+                    yield 2
+                cls = getattr(monsters, mdef.__class__.__name__)
+                dir = mdef.dir
+                i = random.random()
+                while i < f_monsters:
+                    cls(mdef, dir=dir)
+                    dir = -dir
+                    i += 1.0
         self.playingboard = 1
 
     def putwall(self, x, y, w=None):
@@ -590,12 +591,14 @@ def next_board(num=0, complete=1, fastreenter=False):
             num += gamesrv.game.stepboard
             if num >= len(BoardList):
                 num = len(BoardList)-1
+            if (gamesrv.game.finalboard is not None and num > gamesrv.game.finalboard):
+                num = gamesrv.game.finalboard
         for t in brd.leave(inplace=inplace):
             yield t
 
     # reset global board state
-    from player import BubPlayer
-    BubPlayer.__dict__.update(BubPlayer.INIT_BOARD_CAP)
+    from player import BubPlayer, reset_global_board_state
+    reset_global_board_state()
     if not inplace:
         del BubPlayer.MonsterList[:]
         # wait for at least one player
@@ -1163,7 +1166,7 @@ def extra_display_repulse(cx, cy, dlimit=5000, dfactor=1000):
                 dx = (dx*dfactor)//d
                 dy = (dy*dfactor)//d
                 offsets[s] = dx, dy
-                s.setdisplaypos(x+dx, y+dy)
+                s.setdisplaypos(int(x+dx), int(y+dy))
     yield 0
     yield 0
     while offsets:
@@ -1181,7 +1184,7 @@ def extra_display_repulse(cx, cy, dlimit=5000, dfactor=1000):
                     dy -= max(1, dy//5)
                 if dx or dy:
                     offsets[s] = dx, dy
-                s.setdisplaypos(s.x+dx, s.y+dy)
+                s.setdisplaypos(int(s.x+dx), int(s.y+dy))
         yield 0
 
 def extra_bkgnd_black(cx, cy):
