@@ -72,6 +72,7 @@ class Dragon(ActiveSprite):
         self.hatsprite = None
         self.hatangle = 1
         self.isdying = 0
+        self.lifegained = 0
         self.playing_fish = False
         if BubPlayer.SuperSheep:
             self.become_monster('Sheep', immed=1)
@@ -518,6 +519,7 @@ class Dragon(ActiveSprite):
 
     def enter_new_board(self):
         self.playing_fish = False
+        self.lifegained = 0
 
     def become_fish(self):
         self.playing_fish = True
@@ -745,6 +747,7 @@ class BubPlayer(gamesrv.Player):
         self.points = 0
         self.nextextralife = gamesrv.game.extralife
         self.lives = boards.get_lives()
+        self.lifegained = 0
         #self.badpoints = 0
         self.pcap = {}
         self.dragons = []
@@ -822,6 +825,7 @@ class BubPlayer(gamesrv.Player):
         rightplayers = [p for p in players if not p.start_left]
         self.start_left = (len(leftplayers) + random.random() <
                            len(rightplayers) + random.random())
+        self.lifegained = 0
 
     def savecaps(self):
         self.pcap = {}
@@ -927,12 +931,14 @@ class BubPlayer(gamesrv.Player):
             self.points = 0
         while self.points >= self.nextextralife:
             if self.lives is not None and self.lives > 0:
-                if self.dragons:
-                    dragon = random.choice(self.dragons)
-                    dragon.play(images.Snd.Extralife)
-                else:
-                    images.Snd.Extralife.play()
-                self.lives += 1
+                if gamesrv.game.lifegainlimit is None or self.lifegained < gamesrv.game.lifegainlimit:
+                    if self.dragons:
+                        dragon = random.choice(self.dragons)
+                        dragon.play(images.Snd.Extralife)
+                    else:
+                        images.Snd.Extralife.play()
+                    self.lives += 1
+                    self.lifegained += 1
             self.nextextralife += gamesrv.game.extralife
         if self.LimitScoreColor is not None and self.points >= self.LimitScore:
             boards.replace_boardgen(boards.game_over(), 1)
@@ -1180,7 +1186,10 @@ def scoreboard(reset=0, inplace=0, compresslimittime=0):
     else:
         ymin = 0
     if not brd.bonuslevel:
-        xyiconumber(DigitsMisc.digits_white, 2, 2, brd.num+1, lst, width=2)
+        if brd.num < 99:
+            xyiconumber(DigitsMisc.digits_white, 2, 2, brd.num+1, lst, width=2)
+        else:
+            xyiconumber(DigitsMisc.digits_white, 2, 2, brd.num+1, lst, width=3)
 
     # compress the scoreboard vertically if it doesn't fit
     ymin += HALFCELL
@@ -1198,4 +1207,7 @@ def scoreboard(reset=0, inplace=0, compresslimittime=0):
 
 
 # initialize global board data
-BubPlayer.__dict__.update(BubPlayer.INIT_BOARD_CAP)
+def reset_global_board_state():
+    for key, value in BubPlayer.INIT_BOARD_CAP.items():
+        setattr(BubPlayer, key, value)
+reset_global_board_state()
