@@ -192,10 +192,14 @@ class PageServer:
         kwds = {}
         if options.beginboard is not None:
             kwds['beginboard'] = int(options.beginboard)
+        if options.lvlend is not None and options.lvlend.startswith('n'):
+            kwds['finalboard'] = int(options.finalboard)
         if options.stepboard is not None:
             kwds['stepboard'] = int(options.stepboard)
-        if options.limit == 'y':
+        if options.limit is not None and options.limit.startswith('y'):
             kwds['limitlives'] = int(options.lives)
+        if options.limitlifegain is not None:
+            kwds['lifegainlimit'] = int(options.lifegainlimit)
         if options.extralife is not None:
             kwds['extralife'] = int(options.extralife)
         if options.autoreset is not None:
@@ -616,7 +620,7 @@ def schedule_launch(args):
 def launch(args):
     # platform-specific hacks
     print 'Running client ->  ', ' '.join(args)
-    if sys.platform == 'darwin':   # must start as a UI process
+    if 0:  # OLD CODE sys.platform == 'darwin':   # must start as a UI process
         import tempfile
         cmdname = tempfile.mktemp('_BubBob.py')
         f = open(cmdname, 'w')
@@ -683,6 +687,8 @@ else:
                 ROOTDIR = absroot
                 break
         assert s.startswith(absroot)
+        if absroot.endswith(os.sep):    #  'C:\'
+            absroot = absroot[:-1]
         assert s[len(absroot)] == os.sep
         relpath = s[len(absroot)+1:]
         result = os.path.join(ROOTDIR, relpath)
