@@ -3,10 +3,12 @@ from select import select
 from socket import *
 from metastruct import *
 
-METASERVER = ('codespeak.net', 8055)
-METASERVER_UDP = ('codespeak.net', 8055)
-METASERVER_URL = 'http://codespeak.net:8050/bub-n-bros.html'
-VERSION_TAG = 1600
+_SERVER = 'ctpug.org.za'
+
+METASERVER = (_SERVER, 8055)
+METASERVER_UDP = (_SERVER, 8055)
+METASERVER_URL = 'http://%s:8050/bub-n-bros.html' % (_SERVER,)
+VERSION_TAG = 1601
 
 def connect(failure=[]):
     if len(failure) >= 2:
@@ -576,9 +578,14 @@ def print_server_list():
                 if ':' in key:
                     try:
                         addr, _, _ = gethostbyaddr(key[:key.index(':')])
-                        print addr
                     except:
                         pass
+                    else:
+                        addr = '%-27s' % (addr,)
+                        if len(addr) < 28: addr += '|'
+                        addr = '%-60s' % (addr,)
+                        if len(addr) < 61: addr += '|'
+                        print addr
                 value = decodedict(value)
                 print ' %-25s | %-30s | %s' % (
                     key, value.get('desc', '<no description>'),
